@@ -1,7 +1,7 @@
 //
 // acer.h
 //
-// Copyright 2012 - 2014 by John Pietrzak (jpietrzak8@gmail.com)
+// Copyright 2012 - 2015 by John Pietrzak (jpietrzak8@gmail.com)
 //
 // This file is part of Pierogi.
 //
@@ -25,11 +25,12 @@
 
 #include "pirkeysetmetadata.h"
 
-class QObject;
 class QComboBox;
 
 class AcerTV1: public PIRKeysetMetaData
 {
+  Q_OBJECT
+
 public:
   AcerTV1(
     unsigned int index);
@@ -43,6 +44,8 @@ public:
 
 class AcerPC1: public PIRKeysetMetaData
 {
+  Q_OBJECT
+
 public:
   AcerPC1(
     unsigned int index);
