@@ -1,7 +1,7 @@
 //
 // admiral.h
 //
-// Copyright 2012, 2013 by John Pietrzak (jpietrzak8@gmail.com)
+// Copyright 2012 - 2015 by John Pietrzak (jpietrzak8@gmail.com)
 //
 // This file is part of Pierogi.
 //
@@ -25,10 +25,10 @@
 
 #include "pirkeysetmetadata.h"
 
-class QObject;
-
 class AdmiralTV1: public PIRKeysetMetaData
 {
+  Q_OBJECT
+
 public:
   AdmiralTV1(
     unsigned int index);
@@ -39,6 +39,8 @@ public:
 
 class AdmiralTV2: public PIRKeysetMetaData
 {
+  Q_OBJECT
+
 public:
   AdmiralTV2(
     unsigned int index);
@@ -49,6 +51,8 @@ public:
 
 class AdmiralVCR1: public PIRKeysetMetaData
 {
+  Q_OBJECT
+
 public:
   AdmiralVCR1(
     unsigned int index);
