@@ -1,7 +1,7 @@
 //
 // apex.cpp
 //
-// Copyright 2013 by John Pietrzak (jpietrzak8@gmail.com)
+// Copyright 2013 - 2015 by John Pietrzak (jpietrzak8@gmail.com)
 //
 // This file is part of Pierogi.
 //
@@ -46,6 +46,12 @@ void ApexTV1::populateProtocol(
 
   threadableProtocol = new NECProtocol(guiObject, index, false, true);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0x40, 8);
 
   addKey("0", Zero_Key, 0x00, 8);
@@ -108,6 +114,12 @@ void ApexSTB1::populateProtocol(
 
   threadableProtocol = new NECProtocol(guiObject, index, true, true);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0xFB0C, 16);
 
   addKey("0", Zero_Key, 0x04, 8);
@@ -162,6 +174,12 @@ void ApexDVD1::populateProtocol(
 
   threadableProtocol = new NECProtocol(guiObject, index, false, true);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0x04, 8);
 
   addKey("DVD_DIGEST", DiscMenu_Key, 0x00, 8); // "menu"
@@ -268,6 +286,12 @@ void ApexDVD2::populateProtocol(
 
   threadableProtocol = new NECProtocol(guiObject, index, true, true);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0xEE00, 16);
 
   addKey("program", Program_Key, 0x01, 8);
@@ -385,6 +409,12 @@ void ApexDVD3::populateProtocol(
 
   threadableProtocol = new NECProtocol(guiObject, index, false, true);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0x01, 8);
 
   addKey("standby", Power_Key, 0x05, 8);
