@@ -1,7 +1,7 @@
 //
 // bangandolufsen.h
 //
-// Copyright 2014 by John Pietrzak (jpietrzak8@gmail.com)
+// Copyright 2014 - 2015 by John Pietrzak (jpietrzak8@gmail.com)
 //
 // This file is part of Pierogi.
 //
@@ -25,11 +25,12 @@
 
 #include "pirkeysetmetadata.h"
 
-class QObject;
 class QComboBox;
 
 class BangAndOlufsenTV1: public PIRKeysetMetaData
 {
+  Q_OBJECT
+
 public:
   BangAndOlufsenTV1(
     unsigned int index);
