@@ -1,7 +1,7 @@
 //
 // bush.h
 //
-// Copyright 2012, 2013 by John Pietrzak (jpietrzak8@gmail.com)
+// Copyright 2012 - 2015 by John Pietrzak (jpietrzak8@gmail.com)
 //
 // This file is part of Pierogi.
 //
@@ -25,11 +25,12 @@
 
 #include "pirkeysetmetadata.h"
 
-class QObject;
 class QComboBox;
 
 class BushTV1: public PIRKeysetMetaData
 {
+  Q_OBJECT
+
 public:
   BushTV1(
     unsigned int index);
@@ -43,6 +44,8 @@ public:
 
 class BushTV2: public PIRKeysetMetaData
 {
+  Q_OBJECT
+
 public:
   BushTV2(
     unsigned int index);
@@ -53,6 +56,8 @@ public:
 
 class BushSTB1: public PIRKeysetMetaData
 {
+  Q_OBJECT
+
 public:
   BushSTB1(
     unsigned int index);
