@@ -1,7 +1,7 @@
 //
 // canon.h
 //
-// Copyright 2012, 2013 by John Pietrzak (jpietrzak8@gmail.com)
+// Copyright 2012 - 2015 by John Pietrzak (jpietrzak8@gmail.com)
 //
 // This file is part of Pierogi.
 //
@@ -25,10 +25,10 @@
 
 #include "pirkeysetmetadata.h"
 
-class QObject;
-
 class CanonDSLR1: public PIRKeysetMetaData
 {
+  Q_OBJECT
+
 public:
   CanonDSLR1(
     unsigned int index);
@@ -39,6 +39,8 @@ public:
 
 class CanonCamcorder1: public PIRKeysetMetaData
 {
+  Q_OBJECT
+
 public:
   CanonCamcorder1(
     unsigned int index);
@@ -49,6 +51,8 @@ public:
 
 class CanonPowershot1: public PIRKeysetMetaData
 {
+  Q_OBJECT
+
 public:
   CanonPowershot1(
     unsigned int index);
