@@ -1,7 +1,7 @@
 //
 // goodmans.cpp
 //
-// Copyright 2012, 2013 by John Pietrzak (jpietrzak8@gmail.com)
+// Copyright 2012 - 2015 by John Pietrzak (jpietrzak8@gmail.com)
 //
 // This file is part of Pierogi.
 //
@@ -48,6 +48,12 @@ void GoodmansSTB1::populateProtocol(
 
   threadableProtocol = new RC5Protocol(guiObject, index);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   addKey("Power", Power_Key, 0x120C, 13);
   addKey("TV/DTV", Input_Key, 0x120E, 13);
   addKey("MUTE", Mute_Key, 0x120D, 13);
@@ -106,6 +112,12 @@ void GoodmansVCR1::populateProtocol(
 
   threadableProtocol = new NECProtocol(guiObject, index, true, false);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0x7B80, 16);
 
   addKey("VCR_ON", Power_Key, 0x13, 8);
@@ -173,6 +185,12 @@ void GoodmansDVD1::populateProtocol(
 
   threadableProtocol = new NECProtocol(guiObject, index, false, true);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0x00, 8);
 
   addKey("PLAY", Play_Key, 0x47, 8);
@@ -244,6 +262,12 @@ void GoodmansAudio1::populateProtocol(
 
   threadableProtocol = new NECProtocol(guiObject, index, true, true);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0x6C87, 16);
 
   addKey("0", Zero_Key, 0x00, 8);
