@@ -1,7 +1,7 @@
 //
 // huawei.cpp
 //
-// Copyright 2012, 2013 by John Pietrzak (jpietrzak8@gmail.com)
+// Copyright 2012 - 2015 by John Pietrzak (jpietrzak8@gmail.com)
 //
 // This file is part of Pierogi.
 //
@@ -48,6 +48,12 @@ void HuaweiSTB1::populateProtocol(
 
   threadableProtocol = new NECXProtocol(guiObject, index, false);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0x1111, 16);
 
   addKey("5", Five_Key, 0x80, 8);
@@ -111,6 +117,12 @@ void HuaweiSTB2::populateProtocol(
 
   threadableProtocol = new NECProtocol(guiObject, index, false, true);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0x11, 8);
 
   addKey("Red", Red_Key, 0x84, 8);
