@@ -1,7 +1,7 @@
 //
 // kathrein.h
 //
-// Copyright 2012, 2013 by John Pietrzak (jpietrzak8@gmail.com)
+// Copyright 2012 - 2015 by John Pietrzak (jpietrzak8@gmail.com)
 //
 // This file is part of Pierogi.
 //
@@ -25,10 +25,11 @@
 
 #include "pirkeysetmetadata.h"
 
-class QObject;
 
 class KathreinSat1: public PIRKeysetMetaData
 {
+  Q_OBJECT
+
 public:
   KathreinSat1(
     unsigned int index);
@@ -39,6 +40,8 @@ public:
 
 class KathreinSat2: public PIRKeysetMetaData
 {
+  Q_OBJECT
+
 public:
   KathreinSat2(
     unsigned int index);
@@ -49,6 +52,8 @@ public:
 
 class KathreinSat3: public PIRKeysetMetaData
 {
+  Q_OBJECT
+
 public:
   KathreinSat3(
     unsigned int index);
