@@ -1,7 +1,7 @@
 //
 // magnum.cpp
 //
-// Copyright 2012, 2013 by John Pietrzak (jpietrzak8@gmail.com)
+// Copyright 2012 - 2015 by John Pietrzak (jpietrzak8@gmail.com)
 //
 // This file is part of Pierogi.
 //
@@ -47,6 +47,12 @@ void MagnumTV1::populateProtocol(
 
   threadableProtocol = new RC5Protocol(guiObject, index);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   addKey("OK", Select_Key, 0x0057, 13);
   addKey("TOP10", Favorites_Key, 0x0058, 13);
   addKey("CONTRAST+", ContrastUp_Key, 0x0070, 13);
