@@ -1,7 +1,7 @@
 //
 // mce.cpp
 //
-// Copyright 2012, 2013 by John Pietrzak (jpietrzak8@gmail.com)
+// Copyright 2012 - 2015 by John Pietrzak (jpietrzak8@gmail.com)
 //
 // This file is part of Pierogi.
 //
@@ -48,6 +48,12 @@ void MCERemote1::populateProtocol(
 
   threadableProtocol = new MCEProtocol(guiObject, index, 0x800F);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0x04, 7);
 
   addKey("Zero", Zero_Key, 0x00, 8);
