@@ -1,7 +1,7 @@
 //
 // nec.cpp
 //
-// Copyright 2012, 2013 by John Pietrzak (jpietrzak8@gmail.com)
+// Copyright 2012 - 2015 by John Pietrzak (jpietrzak8@gmail.com)
 //
 // This file is part of Pierogi.
 //
@@ -48,6 +48,12 @@ void NECTV1::populateProtocol(
 
   threadableProtocol = new NECProtocol(guiObject, index, false, true);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0x18, 8);
 
   addKey("prog_+", ChannelUp_Key, 0x00, 8);
@@ -125,6 +131,12 @@ void NECVCR1::populateProtocol(
 
   threadableProtocol = new NECProtocol(guiObject, index, false, true);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0x19, 8);
 
   addKey("CHANNEL_UP", ChannelUp_Key, 0x00, 8);
@@ -192,6 +204,12 @@ void NECVCR2::populateProtocol(
 
   threadableProtocol = new NECProtocol(guiObject, index, false, true);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0x6E, 8);
 
   addKey("PLAY", Play_Key, 0x08, 8);
@@ -257,6 +275,12 @@ void NECVCR3::populateProtocol(
 
   threadableProtocol = new NECProtocol(guiObject, index, false, true);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0x31, 8);
 
   addKey("CHANNEL_UP", ChannelUp_Key, 0x01, 8);
@@ -326,6 +350,12 @@ void NECDVD1::populateProtocol(
 
   threadableProtocol = new NECXProtocol(guiObject, index, true);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0x2D2D, 16);
 
   addKey("Power", Power_Key, 0x30, 8);
@@ -393,6 +423,12 @@ void NECProjector1::populateProtocol(
 
   threadableProtocol = new NECProtocol(guiObject, index, false, true);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0x18, 8);
 
   addKey("R", Unmapped_Key, 0x00, 8);
@@ -471,6 +507,12 @@ void NECProjector2::populateProtocol(
 
   threadableProtocol = new NECProtocol(guiObject, index, true, true);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0xE918, 16);
 
   addKey("VIDEO", VideoInput_Key, 0x03, 8);
@@ -556,6 +598,12 @@ void NECProjector3::populateProtocol(
 
   threadableProtocol = new NECProtocol(guiObject, index, true, true);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0xF718, 16);
 
   // These commands are almost the same as keyset 2, but have a few
