@@ -1,7 +1,7 @@
 //
 // pinnacle.h
 //
-// Copyright 2012, 2013 by John Pietrzak (jpietrzak8@gmail.com)
+// Copyright 2012 - 2015 by John Pietrzak (jpietrzak8@gmail.com)
 //
 // This file is part of Pierogi.
 //
@@ -25,10 +25,11 @@
 
 #include "pirkeysetmetadata.h"
 
-class QObject;
 
 class PinnaclePCTV1: public PIRKeysetMetaData
 {
+  Q_OBJECT
+
 public:
   PinnaclePCTV1(
     unsigned int index);
@@ -39,6 +40,8 @@ public:
 
 class PinnaclePCTV2: public PIRKeysetMetaData
 {
+  Q_OBJECT
+
 public:
   PinnaclePCTV2(
     unsigned int index);
@@ -49,6 +52,8 @@ public:
 
 class PinnaclePCTV3: public PIRKeysetMetaData
 {
+  Q_OBJECT
+
 public:
   PinnaclePCTV3(
     unsigned int index);
