@@ -1,7 +1,7 @@
 //
 // saba.cpp
 //
-// Copyright 2012, 2013 by John Pietrzak (jpietrzak8@gmail.com)
+// Copyright 2012 - 2015 by John Pietrzak (jpietrzak8@gmail.com)
 //
 // This file is part of Pierogi.
 //
@@ -45,6 +45,12 @@ void SabaTV1::populateProtocol(
 
   threadableProtocol = new ThomsonProtocol(guiObject, index);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0x0, 4);
 
   addKey("1", One_Key, 0x00, 7);
@@ -109,6 +115,12 @@ void SabaTV2::populateProtocol(
 
   threadableProtocol = new ThomsonProtocol(guiObject, index);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0x3, 4);
 
   addKey("1", One_Key, 0x00, 7);
