@@ -1,7 +1,7 @@
 //
 // universum.cpp
 //
-// Copyright 2012, 2013 by John Pietrzak (jpietrzak8@gmail.com)
+// Copyright 2012 - 2015 by John Pietrzak (jpietrzak8@gmail.com)
 //
 // This file is part of Pierogi.
 //
@@ -49,6 +49,12 @@ void UniversumVCR1::populateProtocol(
 
   threadableProtocol = new NECProtocol(guiObject, index, false, true);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0x31, 8);
 
   addKey("ch/track_+", ChannelUp_Key, 0x01, 8);
@@ -123,6 +129,12 @@ void UniversumVCR2::populateProtocol(
 
   threadableProtocol = new RC5Protocol(guiObject, index);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   addKey("STANDBY", Power_Key, 0x114C, 13);
   addKey("CASS", Eject_Key, 0x017E, 13);
   addKey("TIMER", Timer_Key, 0x115D, 13);
@@ -178,6 +190,12 @@ void UniversumVCR3::populateProtocol(
 
   threadableProtocol = new NECProtocol(guiObject, index, true, false);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0x7B80, 16);
 
   addKey("power", Power_Key, 0x13, 8);
@@ -249,6 +267,12 @@ void UniversumTV1::populateProtocol(
 
   threadableProtocol = new RC5Protocol(guiObject, index);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   addKey("0", Zero_Key, 0x1000, 13);
   addKey("1", One_Key, 0x1001, 13);
   addKey("2", Two_Key, 0x1002, 13);
@@ -367,6 +391,12 @@ void UniversumSat1::populateProtocol(
 
   threadableProtocol = new RC5Protocol(guiObject, index);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   addKey("on", Power_Key, 0x13CC, 13);
   addKey("mute", Mute_Key, 0x13CD, 13);
   addKey("1", One_Key, 0x13C1, 13);
@@ -436,6 +466,12 @@ void UniversumAudio1::populateProtocol(
 
   threadableProtocol = new NECXProtocol(guiObject, index, true);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0x1010, 16);
 
   addKey("FM", FM_Key, 0x00, 8);
