@@ -1,7 +1,7 @@
 //
 // wharfedale.h
 //
-// Copyright 2012, 2013 by John Pietrzak (jpietrzak8@gmail.com)
+// Copyright 2012 - 2015 by John Pietrzak (jpietrzak8@gmail.com)
 //
 // This file is part of Pierogi.
 //
@@ -25,10 +25,11 @@
 
 #include "pirkeysetmetadata.h"
 
-class QObject;
 
 class WharfedaleTV1: public PIRKeysetMetaData
 {
+  Q_OBJECT
+
 public:
   WharfedaleTV1(
     unsigned int index);
@@ -39,6 +40,8 @@ public:
 
 class WharfedaleTV2: public PIRKeysetMetaData
 {
+  Q_OBJECT
+
 public:
   WharfedaleTV2(
     unsigned int index);
